@@ -134,6 +134,12 @@ def test_runtime_install_role(
     result = runtime.exec(["ansible-galaxy", "list"])
     assert result.returncode == 0, result
     assert role_name in result.stdout
+    if isolated:
+        assert pathlib.Path(f"{runtime.cache_dir}/roles/{role_name}").is_symlink()
+    else:
+        assert pathlib.Path(
+            f"{os.path.expanduser(runtime.config.default_roles_path[0])}/{role_name}"
+        ).is_symlink()
     runtime.clean()
     # also test that clean does not break when cache_dir is missing
     tmp_dir = runtime.cache_dir
@@ -460,7 +466,7 @@ def test_install_galaxy_role(runtime_tmp: Runtime) -> None:
     pathlib.Path(f"{runtime_tmp.project_dir}/meta/main.yml").touch()
     # this should only raise a warning
     runtime_tmp._install_galaxy_role(runtime_tmp.project_dir, role_name_check=1)
-    # this shoul test the bypass role name check path
+    # this should test the bypass role name check path
     runtime_tmp._install_galaxy_role(runtime_tmp.project_dir, role_name_check=2)
     # this should raise an error
     with pytest.raises(
@@ -505,6 +511,36 @@ def test_install_galaxy_role_bad_namespace(runtime_tmp: Runtime) -> None:
         runtime_tmp._install_galaxy_role(runtime_tmp.project_dir, role_name_check=1)
 
 
+@pytest.mark.parametrize(
+    "galaxy_info",
+    (
+        """galaxy_info:
+  role_name: foo-bar
+  namespace: acme
+""",
+        """galaxy_info:
+  role_name: foo-bar
+""",
+    ),
+    ids=("bad-name", "bad-name-without-namespace"),
+)
+def test_install_galaxy_role_name_role_name_check_equals_to_1(
+    runtime_tmp: Runtime,
+    galaxy_info: str,
+    caplog: pytest.LogCaptureFixture,
+) -> None:
+    """Check install role with bad role name in galaxy info."""
+    caplog.set_level(logging.WARN)
+    pathlib.Path(f"{runtime_tmp.project_dir}/meta").mkdir()
+    pathlib.Path(f"{runtime_tmp.project_dir}/meta/main.yml").write_text(
+        galaxy_info,
+        encoding="utf-8",
+    )
+
+    runtime_tmp._install_galaxy_role(runtime_tmp.project_dir, role_name_check=1)
+    assert "Computed fully qualified role name of " in caplog.text
+
+
 def test_install_galaxy_role_no_checks(runtime_tmp: Runtime) -> None:
     """Check install role with bad namespace in galaxy info."""
     runtime_tmp.prepare_environment()
@@ -607,16 +643,19 @@ def test_install_collection_from_disk_fail() -> None:
     """Tests that we fail to install a broken collection."""
     with remember_cwd("test/collections/acme.broken"):
         runtime = Runtime(isolated=True)
-        exception: Type[Exception]
-        if runtime.version_in_range(upper="2.11"):
-            exception = AnsibleCommandError
-            msg = "Got 1 exit code while running: ansible-galaxy collection build"
-        else:
-            exception = InvalidPrerequisiteError
-            msg = "is missing the following mandatory"
-        with pytest.raises(exception, match=msg):
-            # this should call install_collection_from_disk(".")
+        with pytest.raises(RuntimeError) as exc_info:
             runtime.prepare_environment(install_local=True)
+        # based on version of Ansible used, we might get a different error,
+        # but both errors should be considered acceptable
+        assert exc_info.type in (
+            RuntimeError,
+            AnsibleCompatError,
+            AnsibleCommandError,
+            InvalidPrerequisiteError,
+        )
+        assert exc_info.match(
+            "(is missing the following mandatory|Got 1 exit code while running: ansible-galaxy collection build)"
+        )
 
 
 def test_prepare_environment_offline_role() -> None:
